==> ejc-skeleton-3.0.0-20250307.083745-350-sources.jar: com/ejianc/framework/skeleton/refer/serialize/ReferSerializer.java <==
package com.ejianc.framework.skeleton.refer.serialize;

import java.io.IOException;
import java.util.Objects;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.LoggerFactory;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.refer.util.ReferObjectUtil;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.BeanProperty;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.introspect.AnnotatedMethod;
import com.fasterxml.jackson.databind.ser.ContextualSerializer;

/**
 * 将String转换成json{id:xx,code:xx,name:xx}
 * <note>将String{id,id}转换成JsonArray[{id:xx,code:xx,name:xx},{id:xx,code:xx,name:
 * xx}]</note>
 * 
 * @author guominga 2020年02月13日
 *
 */

public class ReferSerializer extends JsonSerializer<Object> implements ContextualSerializer {
	private final static org.slf4j.Logger Log = LoggerFactory.getLogger(ReferSerializer.class);

	/**
	 * 实体引用对应code
	 */
	private String referCode;

	private Boolean isString = false; //是否字符串

	private static final String DEFDOC_REFER_CODE = "defdoc";

	public ReferSerializer(String referCode) {
		super();
		this.referCode = referCode;
		this.isString = false;
	}
	public ReferSerializer(String referCode, Boolean isString) {
		super();
		this.referCode = referCode;
		this.isString = isString;
	}

	// 必须要保留无参构造方法
	public ReferSerializer() {
		super();
	}

	@Override
	public void serialize(Object object, JsonGenerator jgen, SerializerProvider provider) throws IOException, JsonProcessingException {
		String value = object.toString();
		String[] ids = StringUtils.isBlank(value) ? null: value.split(",");
		if(ids != null && ids.length > 0) {
			boolean isSingle = ids.length == 1 && value.indexOf(",") == -1;
			JSONArray jsonArray = null;
			String[] referCodeArr = referCode.split(",");
			for(String rc:referCodeArr) {
				try {
					// 单个参照code
					jsonArray = ReferObjectUtil.getReferEntityValue(value, rc);
				} catch (Exception e) {
					try {
						jsonArray = ReferObjectUtil.getReferEntityValue(value, rc);
					} catch (Exception e1) {
						Log.error("referCode:" + referCode + " id：" + value + "转换出错，--" + e.getMessage(), e);
					}
				}
				if(jsonArray != null && jsonArray.size() > 0) {
					break;
				}
			}
			if (jsonArray != null && jsonArray.size() > 0) {
				if(isSingle && !isString) {
					jgen.writeObject(jsonArray.get(0));
				}else{
					jgen.writeObject(jsonArray);
				}
			} else {
				JSONObject result = new JSONObject();
				result.put("id", value);
				result.put("code", value);
				result.put("name", value);
				if(isSingle && !isString) {
					jgen.writeObject(result);
				}else{
					jsonArray = new JSONArray();
					jsonArray.add(result);
					jgen.writeObject(jsonArray);
				}
			}
		}
	}

	@Override
	public JsonSerializer<?> createContextual(SerializerProvider serializerProvider, BeanProperty beanProperty) throws JsonMappingException {
		if (beanProperty != null) { // 为空直接跳过
			if (Objects.equals(beanProperty.getType().getRawClass(), String.class) || Objects.equals(beanProperty.getType().getRawClass(), Long.class)) {
				AnnotatedMethod method = (AnnotatedMethod) beanProperty.getMember();
				ReferSerialTransfer referSerialTransfer = method.getAnnotated().getDeclaredAnnotation(ReferSerialTransfer.class);
				if (referSerialTransfer != null) { // 如果能得到注解，就将注解的value传入ReferSerializer
					String referCode = referSerialTransfer.referCode();
					Boolean isString = false;
					if (StringUtils.isNoneBlank(referCode)) {
						if (DEFDOC_REFER_CODE.equalsIgnoreCase(referCode) || referCode.toLowerCase().startsWith(DEFDOC_REFER_CODE)) {
							referCode = DEFDOC_REFER_CODE;
						}
					}
					String isStringStr = referSerialTransfer.isString();
					if(StringUtils.isNotBlank(isStringStr) && "true".equals(isStringStr.toLowerCase())) {
						isString = true;
					}
					return new ReferSerializer(referCode, isString);
				}
			}
			return serializerProvider.findValueSerializer(beanProperty.getType(), beanProperty);
		}
		return serializerProvider.findNullValueSerializer(beanProperty);
	}

}

==> ejc-skeleton-3.0.1-20240201.035218-11-sources.jar: com/ejianc/framework/skeleton/refer/serialize/ReferSerializer.java <==
package com.ejianc.framework.skeleton.refer.serialize;

import java.io.IOException;
import java.util.Objects;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.LoggerFactory;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.refer.util.ReferObjectUtil;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.BeanProperty;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.introspect.AnnotatedMethod;
import com.fasterxml.jackson.databind.ser.ContextualSerializer;

/**
 * 将String转换成json{id:xx,code:xx,name:xx}
 * <note>将String{id,id}转换成JsonArray[{id:xx,code:xx,name:xx},{id:xx,code:xx,name:
 * xx}]</note>
 * 
 * @author guominga 2020年02月13日
 *
 */

public class ReferSerializer extends JsonSerializer<Object> implements ContextualSerializer {
	private final static org.slf4j.Logger Log = LoggerFactory.getLogger(ReferSerializer.class);

	/**
	 * 实体引用对应code
	 */
	private String referCode;

	private static final String DEFDOC_REFER_CODE = "defdoc";

	public ReferSerializer(String referCode) {
		super();
		this.referCode = referCode;
	}

	// 必须要保留无参构造方法
	public ReferSerializer() {
		super();
	}

	@Override
	public void serialize(Object object, JsonGenerator jgen, SerializerProvider provider) throws IOException, JsonProcessingException {
		String value = object.toString();
		String[] ids = StringUtils.isBlank(value) ? null: value.split(",");
		if(ids != null && ids.length > 0) {
			boolean isSingle = ids.length == 1 && value.indexOf(",") == -1;
			JSONArray jsonArray = null;
			String[] referCodeArr = referCode.split(",");
			for(String rc:referCodeArr) {
				try {
					// 单个参照code
					jsonArray = ReferObjectUtil.getReferEntityValue(value, rc);
				} catch (Exception e) {
					try {
						jsonArray = ReferObjectUtil.getReferEntityValue(value, rc);
					} catch (Exception e1) {
						Log.error("referCode:" + referCode + " id：" + value + "转换出错，--" + e.getMessage(), e);
					}
				}
				if(jsonArray != null && jsonArray.size() > 0) {
					break;
				}
			}
			if (jsonArray != null && jsonArray.size() > 0) {
				if(isSingle) {
					jgen.writeObject(jsonArray.get(0));
				}else{
					jgen.writeObject(jsonArray);
				}
			} else {
				JSONObject result = new JSONObject();
				result.put("id", value);
				result.put("code", value);
				result.put("name", value);
				if(isSingle) {
					jgen.writeObject(result);
				}else{
					jsonArray = new JSONArray();
					jsonArray.add(result);
					jgen.writeObject(jsonArray);
				}
			}
		}
	}

	@Override
	public JsonSerializer<?> createContextual(SerializerProvider serializerProvider, BeanProperty beanProperty) throws JsonMappingException {
		if (beanProperty != null) { // 为空直接跳过
			if (Objects.equals(beanProperty.getType().getRawClass(), String.class) || Objects.equals(beanProperty.getType().getRawClass(), Long.class)) {
				AnnotatedMethod method = (AnnotatedMethod) beanProperty.getMember();
				ReferSerialTransfer referSerialTransfer = method.getAnnotated().getDeclaredAnnotation(ReferSerialTransfer.class);
				if (referSerialTransfer != null) { // 如果能得到注解，就将注解的value传入ReferSerializer
					String referCode = referSerialTransfer.referCode();
					if (StringUtils.isNoneBlank(referCode)) {
						if (DEFDOC_REFER_CODE.equalsIgnoreCase(referCode) || referCode.toLowerCase().startsWith(DEFDOC_REFER_CODE)) {
							referCode = DEFDOC_REFER_CODE;
						}
					}
					return new ReferSerializer(referCode);
				}
			}
			return serializerProvider.findValueSerializer(beanProperty.getType(), beanProperty);
		}
		return serializerProvider.findNullValueSerializer(beanProperty);
	}

}
